<?php
/**
* English language file for phpPgAdmin.  Use this as a basis
* for new translations.
*
* $Id: chinese-utf8-zh_CN.php,v 1.5 2007/12/31 13:00:29 ioguix Exp $
*/
	
	// Language and character set
	$lang['applang'] = '&#31616;&#20307;&#20013;&#25991;&#65288;&#32479;&#19968;&#30721;&#65289;';
	$lang['appcharset'] = 'UTF-8';
	$lang['applocale'] = 'zh_CN.UTF-8';
	$lang['appdbencoding'] = 'UTF8';
	$lang['applangdir'] = 'ltr';
	
	// Welcome
	$lang['strintro'] = '&#36814;&#20351;&#29992; phpPgAdmin&#12290;';
	$lang['strppahome'] = 'phpPgAdmin &#20027;&#39029;';
	$lang['strpgsqlhome'] = 'PostgreSQL &#20027;&#39029;';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'PostgreSQL &#25991;&#26723; (&#26412;&#22320;)';
	$lang['strreportbug'] = '&#25253;&#21578; Bug';
	$lang['strviewfaq'] = '&#26597;&#30475;&#22312;&#32447; FAQ';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/?page=faq';
	
	// Basic strings
	$lang['strlogin'] = '&#30331;&#24405;';
	$lang['strloginfailed'] = '&#30331;&#24405;&#22833;&#36133;';
	$lang['strlogindisallowed'] = '&#20986;&#20110;&#23433;&#20840;&#21407;&#22240;&#31105;&#27490;&#30331;&#24405;&#12290;';
	$lang['strserver'] = '&#26381;&#21153;&#22120;';
	$lang['strservers'] = '&#26381;&#21153;&#22120;';
	$lang['strintroduction'] = '&#20171;&#32461;';
	$lang['strhost'] = '&#20027;&#26426;';
	$lang['strport'] = '&#31471;&#21475;';
	$lang['strlogout'] = '&#27880;&#38144;';
	$lang['strowner'] = '&#25152;&#23646;&#20154;';
	$lang['straction'] = '&#25805;&#20316;';
	$lang['stractions'] = '&#25805;&#20316;';
	$lang['strname'] = '&#21517;&#23383;';
	$lang['strdefinition'] = '&#23450;&#20041;';
	$lang['strproperties'] = '&#23646;&#24615;';
	$lang['strbrowse'] = '&#27983;&#35272;';
	$lang['strenable'] = '&#26377;&#25928;';
	$lang['strdisable'] = '&#26080;&#25928;';
	$lang['strdrop'] = '&#21024;&#38500;';
	$lang['strdropped'] = '&#24050;&#21024;&#38500;';
	$lang['strnull'] = '&#31354;';
	$lang['strnotnull'] = '&#38750;&#31354;';
	$lang['strprev'] = '&#21069;&#19968;&#39029;';
	$lang['strnext'] = '&#19979;&#19968;&#39029;';
	$lang['strfirst'] = '&lt;&lt; &#31532;&#19968;&#39029;';
	$lang['strlast'] = '&#26368;&#21518;&#19968;&#39029; &gt;&gt;';
	$lang['strfailed'] = '&#22833;&#36133;';
	$lang['strcreate'] = '&#21019;&#24314;';
	$lang['strcreated'] = '&#24050;&#21019;&#24314;';
	$lang['strcomment'] = '&#27880;&#37322;';
	$lang['strlength'] = '&#38271;&#24230;';
	$lang['strdefault'] = '&#40664;&#35748;';
	$lang['stralter'] = '&#21464;&#26356;';
	$lang['strok'] = '&#30830;&#35748;';
	$lang['strcancel'] = '&#21462;&#28040;';
	$lang['strac'] = '&#33258;&#21160;&#23436;&#25104;&#26377;&#25928;';
	$lang['strsave'] = '&#20445;&#23384;';
	$lang['strreset'] = '&#37325;&#32622;';
	$lang['strinsert'] = '&#25554;&#20837;';
	$lang['strselect'] = '&#36873;&#25321;';
	$lang['strdelete'] = '&#21024;&#38500;';
	$lang['strupdate'] = '&#26356;&#26032;';
	$lang['strreferences'] = '&#21442;&#32771;';
	$lang['stryes'] = '&#26159;';
	$lang['strno'] = '&#21542;';
	$lang['strtrue'] = 'TRUE';
	$lang['strfalse'] = 'FALSE';
	$lang['stredit'] = '&#32534;&#36753;';
	$lang['strcolumn'] = '&#21015;';
	$lang['strcolumns'] = '&#21015;';
	$lang['strrows'] = '&#34892;';
	$lang['strrowsaff'] = '&#34892;&#24050;&#24433;&#21709;&#65288;&#21464;&#26356;&#65289;&#12290;';
	$lang['strobjects'] = '&#23545;&#35937;(s)';
	$lang['strback'] = '&#36820;&#22238;';
	$lang['strqueryresults'] = '&#26597;&#35810;&#32467;&#26524;';
	$lang['strshow'] = '&#26174;&#31034;';
	$lang['strempty'] = '&#31354;';
	$lang['strlanguage'] = '&#35821;&#35328;';
	$lang['strencoding'] = '&#32534;&#30721;';
	$lang['strvalue'] = '&#20540;';
	$lang['strunique'] = '&#21807;&#19968;';
	$lang['strprimary'] = '&#20027;';
	$lang['strexport'] = '&#23548;&#20986;';
	$lang['strimport'] = '&#23548;&#20837;';
	$lang['strallowednulls'] = '&#20801;&#35768;&#31354;&#20018;';
	$lang['strbackslashn'] = '\N';
	$lang['stremptystring'] = '&#31354; &#23383;&#31526;&#20018;/&#23383;&#27573;';
	$lang['strsql'] = 'SQL&#30721;';
	$lang['stradmin'] = '&#31649;&#29702;';
	$lang['strvacuum'] = '&#28165;&#29702;';
	$lang['stranalyze'] = '&#20998;&#26512;';
	$lang['strclusterindex'] = '&#38598;&#32676;';
	$lang['strclustered'] = '&#38598;&#32676;?';
	$lang['strreindex'] = '&#37325;&#24314;&#32034;&#24341;';
	$lang['strexecute'] = '&#25191;&#34892;';
	$lang['stradd'] = '&#28155;&#21152;';
	$lang['strevent'] = '&#20107;&#20214;';
	$lang['strwhere'] = 'Where';
	$lang['strinstead'] = 'Do Instead';
	$lang['strwhen'] = '&#24403;';
	$lang['strformat'] = '&#26684;&#24335;';
	$lang['strdata'] = '&#25968;&#25454;';
	$lang['strconfirm'] = '&#30830;&#35748;';
	$lang['strexpression'] = '&#34920;&#36798;&#24335;';
	$lang['strellipsis'] = '&#12290;&#12290;&#12290;';
	$lang['strseparator'] = ': ';
	$lang['strexpand'] = '&#25193;&#23637;';
	$lang['strcollapse'] = '&#23849;&#28291;';
	$lang['strexplain'] = '&#35299;&#37322;';
	$lang['strexplainanalyze'] = '&#35299;&#37322;&#20998;&#26512;';
	$lang['strfind'] = '&#26597;&#25214;';
	$lang['stroptions'] = '&#36873;&#39033;';
	$lang['strrefresh'] = '&#21047;&#26032;';
	$lang['strdownload'] = '&#19979;&#36733;';
	$lang['strdownloadgzipped'] = '&#19979;&#36733;&#20351;&#29992;gzip&#21387;&#32553;&#30340;&#25991;&#20214;';
	$lang['strinfo'] = '&#20449;&#24687;';
	$lang['stroids'] = 'OIDs';
	$lang['stradvanced'] = '&#39640;&#32423;';
	$lang['strvariables'] = '&#21464;&#37327;';
	$lang['strprocess'] = '&#36827;&#31243;';
	$lang['strprocesses'] = '&#36827;&#31243;';
	$lang['strsetting'] = '&#35774;&#32622;';
	$lang['streditsql'] = '&#32534;&#36753; SQL';
	$lang['strruntime'] = '&#24635;&#25191;&#34892;&#26102;&#38388;: %s ms';
	$lang['strpaginate'] = '&#20998;&#39029;&#32467;&#26524;';
	$lang['struploadscript'] = '&#25110;&#32773;&#19978;&#20256;&#19968;&#20010; SQL &#33050;&#26412;:';
	$lang['strstarttime'] = '&#24320;&#22987;&#26102;&#38388;';
	$lang['strfile'] = '&#25991;&#20214;';
	$lang['strfileimported'] = '&#25991;&#20214;&#24050;&#23548;&#20837;&#12290;';
	$lang['strtrycred'] = '&#23545;&#25152;&#26377;&#26381;&#21153;&#22120;&#20351;&#29992;&#35813;&#29992;&#25143;&#21517;&#21644;&#23494;&#30721;';
	$lang['stractionsonmultiplelines'] = '&#22810;&#34892;&#19978;&#30340;&#25805;&#20316;';
	$lang['strselectall'] = '&#36873;&#25321;&#25152;&#26377;';
	$lang['strunselectall'] = '&#21462;&#28040;&#36873;&#25321;&#25152;&#26377;';
	$lang['strlocale'] = '&#26412;&#22320;';
	
	// User-supplied SQL history
	$lang['strhistory'] = '&#21382;&#21490;';
	$lang['strnohistory'] = '&#26080;&#21382;&#21490;.';
	$lang['strclearhistory'] = '&#28165;&#31354;&#21382;&#21490;';
	$lang['strdelhistory'] = '&#20174;&#21382;&#21490;&#21024;&#38500;';
	$lang['strconfdelhistory'] = '&#30830;&#23450;&#35201;&#20174;&#21382;&#21490;&#21024;&#38500;&#21527; ?';
	$lang['strconfclearhistory'] = '&#30830;&#23450;&#35201;&#28165;&#31354;&#21382;&#21490;&#21527; ?';
	$lang['strnodatabaseselected'] = '&#35831;&#36873;&#25321;&#19968;&#20010;&#25968;&#25454;&#24211;.';
	
	// Database sizes
	$lang['strsize'] = '&#22823;&#23567;';
	$lang['strbytes'] = '&#23383;&#33410;';
	$lang['strkb'] = 'kB';
	$lang['strmb'] = 'MB';
	$lang['strgb'] = 'GB';
	$lang['strtb'] = 'TB';
	
	// Error handling
	$lang['strnoframes'] = '&#35813;&#31243;&#24207;&#22312;&#20855;&#26377;&#26694;&#26550;&#65288;frames&#65289;&#21151;&#33021;&#30340;&#27983;&#35272;&#22120;&#19978;&#24037;&#20316;&#30340;&#26356;&#22909;&#65292;&#20294;&#26159;&#20063;&#21487;&#20197;&#22312;&#19981;&#25903;&#25345;&#26694;&#26550;&#65288;frames&#65289;&#30340;&#27983;&#35272;&#22120;&#19978;&#24037;&#20316;&#65292;&#35831;&#25353;&#19979;&#38754;&#30340;&#38142;&#25509;&#12290;';
	$lang['strnoframeslink'] = '&#19981;&#20351;&#29992;&#26694;&#26550;&#65288;frames&#65289;';
	$lang['strbadconfig'] = '&#24744;&#30340; config.inc.php &#24050;&#22833;&#25928;&#12290;&#24744;&#38656;&#35201;&#33258;&#34892;&#36890;&#36807; config.inc.php-ist &#24674;&#22797;&#12290;';
	$lang['strnotloaded'] = '&#24744;&#23433;&#35013;&#30340; PHP &#19981;&#25903;&#25345;PostgreSQL&#12290; &#20320;&#38656;&#35201;&#37325;&#26032;&#32534;&#35793;PHP&#24182;&#20351;&#29992; --with-pgsql &#37197;&#32622;&#36873;&#39033;&#12290;';
	$lang['strpostgresqlversionnotsupported'] = '&#29256;&#26412;&#30340;PostgreSQL&#19981;&#34987;&#25903;&#25345;&#12290; &#35831;&#26356;&#26032;&#21040;&#29256;&#26412; %s &#25110;&#26356;&#39640;&#29256;&#26412;&#12290;';
	$lang['strbadschema'] = '&#26080;&#25928;&#30340;&#27169;&#24335;&#12290;';
	$lang['strbadencoding'] = '&#35774;&#23450;&#23458;&#25143;&#31471;&#32534;&#30721;&#38169;&#35823;&#12290;';
	$lang['strsqlerror'] = 'SQL:&#38169;&#35823;';
	$lang['strinstatement'] = '&#22312;&#35821;&#21477;&#65306;';
	$lang['strinvalidparam'] = '&#26080;&#25928;&#30340;&#33050;&#26412;&#21442;&#25968;&#12290;';
	$lang['strnodata'] = '&#26597;&#26080;&#25968;&#25454;&#34892;&#12290;';
	$lang['strnoobjects'] = '&#26597;&#26080;&#23545;&#35937;&#12290;';
	$lang['strrownotunique'] = '&#35813;&#34892;&#26080;&#21807;&#19968;&#32422;&#26463;&#12290;';
	$lang['strnoreportsdb'] = '&#20320;&#19981;&#33021;&#21019;&#24314;&#25253;&#21578;&#25968;&#25454;&#24211;&#12290; &#35831;&#21442;&#38405;INSTALL&#25991;&#20214;&#12290;';
	$lang['strnouploads'] = '&#25991;&#20214;&#19978;&#20256;&#34987;&#31105;&#27490;&#12290;';
	$lang['strimporterror'] = '&#23548;&#20837;&#38169;&#35823;&#12290;';
	$lang['strimporterror-fileformat'] = '&#23548;&#20837;&#38169;&#35823;: &#33258;&#21160;&#35782;&#21035;&#25991;&#20214;&#31867;&#22411;&#22833;&#36133;&#12290;';
	$lang['strimporterrorline'] = '&#23548;&#20837;&#38169;&#35823;&#65292;&#20986;&#38169;&#34892; %s&#12290;';
	$lang['strimporterrorline-badcolumnnum'] = '&#23548;&#20837;&#38169;&#35823;&#65292;&#20986;&#38169;&#34892; %s:  &#35813;&#34892;&#21015;&#25968;&#19981;&#27491;&#30830;&#12290;';
	$lang['strimporterror-uploadedfile'] = '&#23548;&#20837;&#38169;&#35823;: &#25991;&#20214;&#19981;&#33021;&#19978;&#20256;&#21040;&#26381;&#21153;&#22120;';
	$lang['strcannotdumponwindows'] = '&#22797;&#26434;&#34920;&#21644;&#27169;&#24335;&#21517;&#31216;&#30340;&#36716;&#20648;&#22312;Windows &#19981;&#34987;&#25903;&#25345;&#12290;';
	$lang['strinvalidserverparam'] = '&#23581;&#35797;&#29992;&#26080;&#25928;&#30340;&#26381;&#21153;&#22120;&#21442;&#25968;&#36830;&#25509;,&#21487;&#33021;&#26377;&#20154;&#27491;&#23581;&#35797;&#25915;&#20987;&#20320;&#30340;&#31995;&#32479;&#12290;';
	$lang['strnoserversupplied'] = '&#27809;&#26377;&#36873;&#25321;&#25968;&#25454;&#24211;!';
	
	// Tables
	$lang['strtable'] = '&#25968;&#25454;&#34920;';
	$lang['strtables'] = '&#25968;&#25454;&#34920;';
	$lang['strshowalltables'] = '&#26174;&#31034;&#31034;&#25152;&#26377;&#34920;&#12290;';
	$lang['strnotables'] = '&#26597;&#26080;&#25968;&#25454;&#34920;&#12290;';
	$lang['strnotable'] = '&#26597;&#26080;&#27492;&#34920;&#12290;';
	$lang['strcreatetable'] = '&#21019;&#24314;&#34920;';
	$lang['strcreatetablelike'] = '&#21019;&#24314;&#34920;&#20174;';
	$lang['strcreatetablelikeparent'] = '&#28304;&#34920;';
	$lang['strcreatelikewithdefaults'] = '&#21253;&#21547;&#40664;&#35748;&#20540;';
	$lang['strcreatelikewithconstraints'] = '&#21253;&#21547;&#32422;&#26463;';
	$lang['strcreatelikewithindexes'] = '&#21253;&#21547;&#34920;&#21517;';
	$lang['strtablename'] = '&#34920;&#21517;';
	$lang['strtableneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#34920;&#21517;&#12290;';
	$lang['strtablelikeneedslike'] = '&#24517;&#39035;&#25351;&#23450;&#35201;&#25335;&#36125;&#30340;&#23646;&#24615;&#25152;&#23646;&#30340;&#25968;&#25454;&#34920;.';
	$lang['strtableneedsfield'] = '&#24517;&#39035;&#33267;&#23569;&#25351;&#23450;&#19968;&#20010;&#23383;&#27573;&#12290;';
	$lang['strtableneedscols'] = '&#24517;&#39035;&#25351;&#23450;&#19968;&#20010;&#26377;&#25928;&#30340;&#21015;&#25968;&#12290;';
	$lang['strtablecreated'] = '&#25968;&#25454;&#34920;&#24050;&#21019;&#24314;&#12290;';
	$lang['strtablecreatedbad'] = '&#25968;&#25454;&#34920;&#21019;&#24314;&#22833;&#36133;';
	$lang['strconfdroptable'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&quot;%s&quot;&#25968;&#25454;&#34920;&#21527;&#65311;';
	$lang['strtabledropped'] = '&#25968;&#25454;&#34920;&#24050;&#21024;&#38500;&#12290;';
	$lang['strtabledroppedbad'] = '&#25968;&#25454;&#34920;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strconfemptytable'] = '&#30830;&#23450;&#35201;&#28165;&#31354;&quot;%s&quot;&#25968;&#25454;&#34920;&#21527;&#65311;';
	$lang['strtableemptied'] = '&#25968;&#25454;&#34920;&#24050;&#28165;&#31354;&#12290;';
	$lang['strtableemptiedbad'] = '&#25968;&#25454;&#34920;&#28165;&#31354;&#22833;&#36133;&#12290;';
	$lang['strinsertrow'] = '&#25554;&#20837;&#34892;';
	$lang['strrowinserted'] = '&#34892;&#24050;&#25554;&#20837;&#12290;';
	$lang['strrowinsertedbad'] = '&#34892;&#25554;&#20837;&#22833;&#36133;&#12290;';
	$lang['strrowduplicate'] = '&#34892;&#25554;&#20837;&#22833;&#36133;, &#23581;&#35797;&#20877;&#27425;&#25554;&#20837;&#12290;';
	$lang['streditrow'] = '&#32534;&#36753;&#34892;';
	$lang['strrowupdated'] = '&#34892;&#24050;&#26356;&#26032;&#12290;';
	$lang['strrowupdatedbad'] = '&#34892;&#26356;&#26032;&#22833;&#36133;&#12290;';
	$lang['strdeleterow'] = '&#21024;&#38500;&#34892;';
	$lang['strconfdeleterow'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#35813;&#34892;&#21527;&#65311;';
	$lang['strrowdeleted'] = '&#34892;&#24050;&#21024;&#38500;&#12290;';
	$lang['strrowdeletedbad'] = '&#34892;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strinsertandrepeat'] = '&#25554;&#20837; &amp; &#26367;&#25442;';
	$lang['strnumcols'] = '&#21015;&#25968;&#30446;';
	$lang['strcolneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#21015;&#21517;';
	$lang['strselectallfields'] = '&#36873;&#25321;&#25152;&#26377;&#23383;&#27573;';
	$lang['strselectneedscol'] = '&#24517;&#39035;&#33267;&#23569;&#26174;&#31034;&#19968;&#21015;&#12290;';
	$lang['strselectunary'] = '&#21333;&#39033;&#25805;&#20316;&#19981;&#33021;&#26377;&#20540;&#12290;';
	$lang['strcolumnaltered'] = '&#21015;&#24050;&#21464;&#26356;&#12290;';
	$lang['strcolumnalteredbad'] = '&#21015;&#21464;&#26356;&#22833;&#36133;&#12290;';
	$lang['strconfdropcolumn'] = '&#30830;&#23450;&#35201;&#23558;&#21015; &quot;%s&quot; &#20174;&#34920; &quot;%s&quot; &#20013;&#21024;&#38500;&#21527;?';
	$lang['strcolumndropped'] = '&#21015;&#24050;&#21024;&#38500;&#12290;';
	$lang['strcolumndroppedbad'] = '&#21015;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['straddcolumn'] = '&#28155;&#21152;&#21015;';
	$lang['strcolumnadded'] = '&#21015;&#24050;&#28155;&#21152;&#12290;';
	$lang['strcolumnaddedbad'] = '&#21015;&#28155;&#21152;&#22833;&#36133;&#12290;';
	$lang['strcascade'] = 'CASCADE';
	$lang['strtablealtered'] = '&#25968;&#25454;&#34920;&#24050;&#21464;&#26356;&#12290;';
	$lang['strtablealteredbad'] = '&#25968;&#25454;&#34920;&#21464;&#26356;&#22833;&#36133;&#12290;';
	$lang['strdataonly'] = '&#20165;&#25968;&#25454;';
	$lang['strstructureonly'] = '&#20165;&#32467;&#26500;';
	$lang['strstructureanddata'] = '&#32467;&#26500;&#21644;&#25968;&#25454;';
	$lang['strtabbed'] = '&#22266;&#23450;&#65288;Tabbed&#65289;';
	$lang['strauto'] = '&#33258;&#21160;';
	$lang['strconfvacuumtable'] = '&#30830;&#23450;&#35201;&#28165;&#29702; &quot;%s&quot;&#21527;?';
	$lang['strconfanalyzetable'] = '&#30830;&#23450;&#35201;&#20998;&#26512; &quot;%s&quot; &#21527;?';
	$lang['strestimatedrowcount'] = '&#20272;&#35745;&#30340;&#34892;&#25968;';
	$lang['strspecifytabletoanalyze'] = '&#24517;&#39035;&#33267;&#23569;&#36873;&#25321;&#19968;&#20010;&#34920;&#26469;&#20998;&#26512;';
	$lang['strspecifytabletoempty'] = '&#24517;&#39035;&#33267;&#23569;&#36873;&#25321;&#19968;&#20010;&#34920;&#26469;&#28165;&#31354;';
	$lang['strspecifytabletodrop'] = '&#24517;&#39035;&#33267;&#23569;&#36873;&#25321;&#19968;&#20010;&#34920;&#26469;&#31227;&#38500;';
	$lang['strspecifytabletovacuum'] = '&#24517;&#39035;&#33267;&#23569;&#36873;&#25321;&#19968;&#20010;&#34920;&#26469;&#28165;&#29702;&#65288;vacuum&#65289;';
	
	// Columns
	$lang['strcolprop'] = '&#21015;&#23646;&#24615;';
	$lang['strnotableprovided'] = '&#27809;&#26377;&#25351;&#34920;!';
	
	// Users
	$lang['struser'] = '&#29992;&#25143;';
	$lang['strusers'] = '&#29992;&#25143;';
	$lang['strusername'] = '&#29992;&#21517;';
	$lang['strpassword'] = '&#23494;&#30721;';
	$lang['strsuper'] = '&#36229;&#32423;&#29992;&#25143;';
	$lang['strcreatedb'] = '&#21019;&#24314;&#25968;&#25454;&#24211;&#65311;';
	$lang['strexpires'] = '&#36807;&#26399;';
	$lang['strsessiondefaults'] = '&#20250;&#35805;&#40664;&#35748;';
	$lang['strnousers'] = '&#26597;&#26080;&#27492;&#29992;&#25143;&#12290;';
	$lang['struserupdated'] = '&#29992;&#25143;&#24050;&#26356;&#26032;&#12290;';
	$lang['struserupdatedbad'] = '&#29992;&#25143;&#26356;&#26032;&#22833;&#36133;&#12290;';
	$lang['strshowallusers'] = '&#26174;&#31034;&#25152;&#26377;&#29992;&#25143;';
	$lang['strcreateuser'] = '&#21019;&#24314;&#29992;&#25143;';
	$lang['struserneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#29992;&#25143;&#21517;&#31216;&#12290;';
	$lang['strusercreated'] = '&#29992;&#25143;&#24050;&#21019;&#24314;&#12290;';
	$lang['strusercreatedbad'] = '&#29992;&#25143;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdropuser'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#29992;&#25143;&quot;%s&quot;&#21527;&#65311;';
	$lang['struserdropped'] = '&#29992;&#25143;&#24050;&#21024;&#38500;&#12290;';
	$lang['struserdroppedbad'] = '&#29992;&#25143;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['straccount'] = '&#24080;&#25143;';
	$lang['strchangepassword'] = '&#20462;&#25913;&#23494;&#30721;';
	$lang['strpasswordchanged'] = '&#23494;&#30721;&#24050;&#20462;&#25913;&#12290;';
	$lang['strpasswordchangedbad'] = '&#23494;&#30721;&#20462;&#25913;&#22833;&#36133;&#12290;';
	$lang['strpasswordshort'] = '&#23494;&#30721;&#22826;&#30701;&#20102;&#12290;';
	$lang['strpasswordconfirm'] = '&#23494;&#30721;&#19981;&#21305;&#37197;&#12290;';
	
	// Groups
	$lang['strgroup'] = '&#32676;&#32452;';
	$lang['strgroups'] = '&#32676;&#32452;';
	$lang['strshowallgroups'] = '&#26174;&#31034;&#25152;&#26377;&#32676;&#32452;';
	$lang['strnogroup'] = '&#26597;&#26080;&#27492;&#32676;&#32452;&#12290;';
	$lang['strnogroups'] = '&#26597;&#26080;&#32676;&#32452;&#12290;';
	$lang['strcreategroup'] = '&#21019;&#24314;&#32676;&#32452;';
	$lang['strgroupneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#32676;&#32452;&#21517;&#31216;&#12290;';
	$lang['strgroupcreated'] = '&#32676;&#32452;&#24050;&#21019;&#24314;&#12290;';
	$lang['strgroupcreatedbad'] = '&#32676;&#32452;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdropgroup'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#32676;&#32452;&quot;%s&quot;&#21527;&#65311;';
	$lang['strgroupdropped'] = '&#32676;&#32452;&#24050;&#21024;&#38500;&#12290;';
	$lang['strgroupdroppedbad'] = '&#32676;&#32452;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strmembers'] = '&#25104;&#21592;';
	$lang['strmemberof'] = '&#25152;&#23646;&#25104;&#21592;';
	$lang['stradminmembers'] = '&#31649;&#29702;&#25104;&#21592;';
	$lang['straddmember'] = '&#28155;&#21152;&#25104;&#21592;';
	$lang['strmemberadded'] = '&#25104;&#21592;&#24050;&#28155;&#21152;&#12290;';
	$lang['strmemberaddedbad'] = '&#25104;&#21592;&#28155;&#21152;&#22833;&#36133;&#12290;';
	$lang['strdropmember'] = '&#21024;&#38500;&#25104;&#21592;';
	$lang['strconfdropmember'] = '&#30830;&#23450;&#35201;&#23558;&#25104;&#21592; &quot;%s&quot; &#20174;&#32676;&#32452; &quot;%s&quot;&#20013;&#21024;&#38500;&#21527;?';
	$lang['strmemberdropped'] = '&#25104;&#21592;&#24050;&#21024;&#38500;&#12290;';
	$lang['strmemberdroppedbad'] = '&#25104;&#21592;&#21024;&#38500;&#22833;&#36133;&#12290;';
	
	// Roles
	$lang['strrole'] = '&#35282;&#33394;';
	$lang['strroles'] = '&#35282;&#33394;';
	$lang['strshowallroles'] = '&#26174;&#31034;&#25152;&#26377;&#35282;&#33394;';
	$lang['strnoroles'] = '&#26597;&#26080;&#35282;&#33394;&#12290;';
	$lang['strinheritsprivs'] = '&#32487;&#25215;&#29305;&#26435;?';
	$lang['strcreaterole'] = '&#21019;&#24314;&#35282;&#33394;';
	$lang['strcancreaterole'] = '&#21019;&#24314;&#35282;&#33394;?';
	$lang['strrolecreated'] = '&#35282;&#33394;&#24050;&#21019;&#24314;&#12290;';
	$lang['strrolecreatedbad'] = '&#35282;&#33394;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strrolealtered'] = '&#35282;&#33394;&#24050;&#21464;&#26356;&#12290;';
	$lang['strrolealteredbad'] = '&#35282;&#33394;&#21464;&#26356;&#22833;&#36133;&#12290;';
	$lang['strcanlogin'] = '&#21487;&#20197;&#30331;&#24405;?';
	$lang['strconnlimit'] = '&#36830;&#25509;&#38480;&#21046;';
	$lang['strdroprole'] = '&#21024;&#38500;&#35282;&#33394;';
	$lang['strconfdroprole'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#35282;&#33394; &quot;%s&quot;&#21527;?';
	$lang['strroledropped'] = '&#35282;&#33394;&#24050;&#21024;&#38500;&#12290;';
	$lang['strroledroppedbad'] = '&#35282;&#33394;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strnolimit'] = '&#26080;&#38480;&#21046;';
	$lang['strnever'] = '&#20174;&#19981;';
	$lang['strroleneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#35282;&#33394;&#21517;&#31216;&#12290;';
	
	// Privileges
	$lang['strprivilege'] = '&#29305;&#26435;';
	$lang['strprivileges'] = '&#29305;&#26435;';
	$lang['strnoprivileges'] = '&#36825;&#20010;&#23545;&#35937;&#25317;&#26377;&#40664;&#35748;&#25152;&#23646;&#20154;&#30340;&#29305;&#26435;&#12290;';
	$lang['strgrant'] = '&#36171;&#20104;';
	$lang['strrevoke'] = '&#25764;&#22238;';
	$lang['strgranted'] = '&#29305;&#26435;&#24050;&#25913;&#21464;';
	$lang['strgrantfailed'] = '&#29305;&#26435;&#25913;&#21464;&#22833;&#36133;';
	$lang['strgrantbad'] = '&#24517;&#39035;&#25351;&#23450;&#33267;&#23569;&#19968;&#20010;&#29992;&#25143;&#25110;&#19968;&#20010;&#32452;&#21644;&#19968;&#20010;&#29305;&#26435;&#12290;';
	$lang['strgrantor'] = '&#36171;&#20104;&#32773;';
	$lang['strasterisk'] = '*';
	
	// Databases
	$lang['strdatabase'] = '&#25968;&#25454;&#24211;';
	$lang['strdatabases'] = '&#25968;&#25454;&#24211;';
	$lang['strshowalldatabases'] = '&#26174;&#31034;&#25152;&#26377;&#25968;&#25454;&#24211;';
	$lang['strnodatabases'] = '&#26597;&#26080;&#25968;&#25454;&#24211;&#12290;';
	$lang['strcreatedatabase'] = '&#21019;&#24314;&#25968;&#25454;&#24211;';
	$lang['strdatabasename'] = '&#25968;&#25454;&#24211;&#21517;&#31216;';
	$lang['strdatabaseneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#25968;&#25454;&#24211;&#21517;&#31216;&#12290;';
	$lang['strdatabasecreated'] = '&#25968;&#25454;&#24211;&#24050;&#21019;&#24314;&#12290;';
	$lang['strdatabasecreatedbad'] = '&#25968;&#25454;&#24211;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdropdatabase'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#25968;&#25454;&#24211;&quot;%s&quot;&#21527;&#65311;';
	$lang['strdatabasedropped'] = '&#25968;&#25454;&#24211;&#24050;&#21024;&#38500;&#12290;';
	$lang['strdatabasedroppedbad'] = '&#25968;&#25454;&#24211;&#21024;&#38500;&#22833;&#36133;';
	$lang['strentersql'] = '&#35831;&#22312;&#19979;&#26041;&#36755;&#20837;&#35201;&#25191;&#34892;&#30340;SQL&#35821;&#21477;&#65306;';
	$lang['strsqlexecuted'] = 'SQL &#24050;&#25191;&#34892;&#12290;';
	$lang['strvacuumgood'] = '&#28165;&#29702;&#23436;&#25104;';
	$lang['strvacuumbad'] = '&#28165;&#29702;&#22833;&#36133;';
	$lang['stranalyzegood'] = '&#20998;&#26512;&#23436;&#25104;';
	$lang['stranalyzebad'] = '&#20998;&#26512;&#22833;&#36133;';
	$lang['strreindexgood'] = '&#37325;&#24314;&#32034;&#24341;&#23436;&#25104;&#12290;';
	$lang['strreindexbad'] = '&#37325;&#24314;&#32034;&#24341;&#22833;&#36133;&#12290;';
	$lang['strfull'] = '&#23436;&#20840;';
	$lang['strfreeze'] = '&#20923;&#32467;';
	$lang['strforce'] = '&#24378;&#21046;';
	$lang['strsignalsent'] = '&#20449;&#21495;&#24050;&#21457;&#36865;&#12290;';
	$lang['strsignalsentbad'] = '&#20449;&#21495;&#21457;&#36865;&#22833;&#36133;&#12290;';
	$lang['strallobjects'] = '&#25152;&#26377;&#23545;&#35937;';
	$lang['strdatabasealtered'] = '&#25968;&#25454;&#24211;&#24050;&#21464;&#26356;&#12290;';
	$lang['strdatabasealteredbad'] = '&#25968;&#25454;&#24211;&#21464;&#26356;&#22833;&#36133;&#12290;';
	$lang['strspecifydatabasetodrop'] = '&#24517;&#39035;&#33267;&#23569;&#25351;&#23450;&#19968;&#20010;&#25968;&#25454;&#24211;&#26469;&#31227;&#38500;';
	
	// Views
	$lang['strview'] = '&#35270;&#22270;';
	$lang['strviews'] = '&#35270;&#22270;';
	$lang['strshowallviews'] = '&#26174;&#31034;&#25152;&#26377;&#35270;&#22270;';
	$lang['strnoview'] = '&#26597;&#26080;&#27492;&#35270;&#22270;';
	$lang['strnoviews'] = '&#26597;&#26080;&#35270;&#22270;&#12290;';
	$lang['strcreateview'] = '&#21019;&#24314;&#35270;&#22270;';
	$lang['strviewname'] = '&#35270;&#22270;&#21517;&#31216;';
	$lang['strviewneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#35270;&#22270;&#21517;&#31216;&#12290;';
	$lang['strviewneedsdef'] = '&#24517;&#39035;&#25351;&#23450;&#35270;&#22270;&#23450;&#20041;&#12290;';
	$lang['strviewneedsfields'] = '&#24517;&#39035;&#25351;&#23450;&#35270;&#22270;&#37324;&#35201;&#36873;&#25321;&#30340;&#21015;&#12290;';
	$lang['strviewcreated'] = '&#35270;&#22270;&#24050;&#21019;&#24314;&#12290;';
	$lang['strviewcreatedbad'] = '&#35270;&#22270;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdropview'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#35270;&#22270;&quot;%s&quot;&#21527;&#65311;';
	$lang['strviewdropped'] = '&#35270;&#22270;&#24050;&#21024;&#38500;&#12290;';
	$lang['strviewdroppedbad'] = '&#35270;&#22270;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strviewupdated'] = '&#35270;&#22270;&#24050;&#26356;&#26032;&#12290;';
	$lang['strviewupdatedbad'] = '&#35270;&#22270;&#26356;&#26032;&#22833;&#36133;';
	$lang['strviewlink'] = '&#36830;&#25509;&#20851;&#38190;&#23383;&#65288;Linking keys&#65289;';
	$lang['strviewconditions'] = '&#38468;&#21152;&#26465;&#20214;';
	$lang['strcreateviewwiz'] = '&#20351;&#29992;&#21521;&#23548;&#21019;&#24314;&#35270;&#22270;';
	$lang['strrenamedupfields'] = '&#37325;&#21629;&#21517;&#22797;&#21046;&#30340;&#23383;&#27573;';
	$lang['strdropdupfields'] = '&#31227;&#38500;&#22797;&#21046;&#30340;&#23383;&#27573;';
	$lang['strerrordupfields'] = '&#22797;&#21046;&#23383;&#27573;&#26102;&#21457;&#29983;&#38169;&#35823;';
	$lang['strviewaltered'] = '&#35270;&#22270;&#24050;&#21464;&#26356;&#12290;';
	$lang['strviewalteredbad'] = '&#35270;&#22270;&#21464;&#26356;&#22833;&#36133;&#12290;';
	$lang['strspecifyviewtodrop'] = '&#24517;&#39035;&#33267;&#23569;&#25351;&#23450;&#19968;&#20010;&#35270;&#22270;&#26469;&#31227;&#38500;';
	
	// Sequences
	$lang['strsequence'] = '&#24207;&#21015;';
	$lang['strsequences'] = '&#24207;&#21015;';
	$lang['strshowallsequences'] = '&#26174;&#31034;&#25152;&#26377;&#24207;&#21015;';
	$lang['strnosequence'] = '&#26597;&#26080;&#27492;&#24207;&#21015;';
	$lang['strnosequences'] = '&#26597;&#26080;&#24207;&#21015;&#12290;';
	$lang['strcreatesequence'] = '&#21019;&#24314;&#24207;&#21015;';
	$lang['strlastvalue'] = '&#26368;&#21518;&#20540;';
	$lang['strincrementby'] = '&#22686;&#37327;';
	$lang['strstartvalue'] = '&#36215;&#22987;&#20540;';
	$lang['strmaxvalue'] = '&#26368;&#22823;&#20540;';
	$lang['strminvalue'] = '&#26368;&#23567;&#20540;';
	$lang['strcachevalue'] = '&#32531;&#23384;&#20540;';
	$lang['strlogcount'] = '&#26085;&#24535;&#35745;&#25968;&#65288;Log count&#65289;';
	$lang['strcancycle'] = '&#21487;&#20197;&#24490;&#29615;&#21527;?';
	$lang['striscalled'] = '&#23558;&#22312;&#36820;&#22238;&#19979;&#19968;&#20010;&#20540;&#21069;&#36882;&#22686;&#26368;&#21518;&#30340;&#20540;(is_called)&#21527;&#65311;';
	$lang['strsequenceneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#24207;&#21015;&#21517;&#31216;&#12290;';
	$lang['strsequencecreated'] = '&#24207;&#21015;&#24050;&#21019;&#24314;&#12290;';
	$lang['strsequencecreatedbad'] = '&#24207;&#21015;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdropsequence'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#24207;&#21015;&quot;%s&quot;&#21527;&#65311;';
	$lang['strsequencedropped'] = '&#24207;&#21015;&#24050;&#21024;&#38500;&#12290;';
	$lang['strsequencedroppedbad'] = '&#24207;&#21015;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strsequencereset'] = '&#24207;&#21015;&#24050;&#37325;&#32622;&#12290;';
	$lang['strsequenceresetbad'] = '&#24207;&#21015;&#37325;&#32622;&#22833;&#36133;&#12290;';
	$lang['strsequencealtered'] = '&#24207;&#21015;&#24050;&#21464;&#26356;&#12290;';
	$lang['strsequencealteredbad'] = '&#24207;&#21015;&#21464;&#26356;&#22833;&#36133;&#12290;';
	$lang['strsetval'] = '&#35774;&#23450;&#24207;&#21015;&#20540;';
	$lang['strsequencesetval'] = '&#24207;&#21015;&#20540;&#24050;&#35774;&#23450;&#12290;';
	$lang['strsequencesetvalbad'] = '&#24207;&#21015;&#20540;&#35774;&#32622;&#22833;&#36133;&#12290;';
	$lang['strnextval'] = '&#36882;&#22686;&#24207;&#21015;&#20540;';
	$lang['strsequencenextval'] = '&#24207;&#21015;&#20540;&#24050;&#36882;&#22686;&#12290;';
	$lang['strsequencenextvalbad'] = '&#24207;&#21015;&#20540;&#36882;&#22686;&#22833;&#36133;&#12290;';
	$lang['strspecifysequencetodrop'] = '&#24517;&#39035;&#33267;&#23569;&#25351;&#23450;&#19968;&#20010;&#24207;&#21015;&#26469;&#21024;&#38500;';
	
	// Indexes
	$lang['strindex'] = '&#32034;&#24341;';
	$lang['strindexes'] = '&#32034;&#24341;';
	$lang['strindexname'] = '&#32034;&#24341;&#21517;';
	$lang['strshowallindexes'] = '&#26174;&#31034;&#25152;&#26377;&#32034;&#24341;';
	$lang['strnoindex'] = '&#26597;&#26080;&#27492;&#32034;&#24341;';
	$lang['strnoindexes'] = '&#26597;&#26080;&#32034;&#24341;';
	$lang['strcreateindex'] = '&#21019;&#24314;&#32034;&#24341;';
	$lang['strtabname'] = '&#25968;&#25454;&#34920;&#21517;';
	$lang['strcolumnname'] = '&#21015;&#21517;';
	$lang['strindexneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#32034;&#24341;&#21517;&#31216;&#12290;';
	$lang['strindexneedscols'] = '&#24517;&#39035;&#32473;&#32034;&#24341;&#25351;&#23450;&#26377;&#25928;&#30340;&#21015;&#25968;&#12290;';
	$lang['strindexcreated'] = '&#32034;&#24341;&#24050;&#21019;&#24314;';
	$lang['strindexcreatedbad'] = '&#32034;&#24341;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdropindex'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&quot;%s&quot;&#32034;&#24341;&#65311;';
	$lang['strindexdropped'] = '&#32034;&#24341;&#24050;&#21024;&#38500;&#12290;';
	$lang['strindexdroppedbad'] = '&#32034;&#24341;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strkeyname'] = '&#38190;&#21517;';
	$lang['struniquekey'] = '&#21807;&#19968;&#38190;';
	$lang['strprimarykey'] = '&#20027;&#38190;';
	$lang['strindextype'] = '&#32034;&#24341;&#31867;&#22411;';
	$lang['strtablecolumnlist'] = '&#34920;&#20013;&#30340;&#21015;';
	$lang['strindexcolumnlist'] = '&#32034;&#24341;&#20013;&#30340;&#21015;';
	$lang['strconfcluster'] = '&#30830;&#23450;&#35201;&#38598;&#32676; &quot;%s&quot;&#21527;?';
	$lang['strclusteredgood'] = '&#38598;&#32676;&#23436;&#25104;&#12290;';
	$lang['strclusteredbad'] = '&#38598;&#32676;&#22833;&#36133;&#12290;';
	
	// Rules
	$lang['strrules'] = '&#35268;&#21017;';
	$lang['strrule'] = '&#35268;&#21017;';
	$lang['strshowallrules'] = '&#26174;&#31034;&#25152;&#26377;&#35268;&#21017;';
	$lang['strnorule'] = '&#26597;&#26080;&#27492;&#35268;&#21017;&#12290;';
	$lang['strnorules'] = '&#26597;&#26080;&#35268;&#21017;';
	$lang['strcreaterule'] = '&#21019;&#24314;&#35268;&#21017;';
	$lang['strrulename'] = '&#35268;&#21017;&#21517;&#31216;';
	$lang['strruleneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#35268;&#21017;&#21517;&#31216;&#12290;';
	$lang['strrulecreated'] = '&#35268;&#21017;&#24050;&#21019;&#24314;&#12290;';
	$lang['strrulecreatedbad'] = '&#35268;&#21017;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdroprule'] = '&#30830;&#23450;&#35201;&#23558;&#35268;&#21017;&quot;%s&quot;&#20174;&quot;%s&quot;&#20013;&#21024;&#38500;&#21527;&#65311;';
	$lang['strruledropped'] = '&#35268;&#21017;&#24050;&#21024;&#38500;&#12290;';
	$lang['strruledroppedbad'] = '&#35268;&#21017;&#21024;&#38500;&#22833;&#36133;&#12290;';
	
	// Constraints
	$lang['strconstraint'] = '&#32422;&#26463;';
	$lang['strconstraints'] = '&#32422;&#26463;';
	$lang['strshowallconstraints'] = '&#26174;&#31034;&#25152;&#26377;&#32422;&#26463;&#12290;';
	$lang['strnoconstraints'] = '&#26597;&#26080;&#27492;&#32422;&#26463;&#12290;';
	$lang['strcreateconstraint'] = '&#21019;&#24314;&#32422;&#26463;';
	$lang['strconstraintcreated'] = '&#32422;&#26463;&#24050;&#21019;&#24314;&#12290;';
	$lang['strconstraintcreatedbad'] = '&#32422;&#26463;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdropconstraint'] = '&#30830;&#23450;&#35201;&#23558;&#24378;&#21046;&quot;%s&quot;&#20174;&quot;%s&quot;&#20013;&#21024;&#38500;&#21527;&#65311;';
	$lang['strconstraintdropped'] = '&#32422;&#26463;&#24050;&#21024;&#38500;&#12290;';
	$lang['strconstraintdroppedbad'] = '&#32422;&#26463;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['straddcheck'] = '&#28155;&#21152;&#26816;&#26597;&#32422;&#26463;';
	$lang['strcheckneedsdefinition'] = '&#24517;&#39035;&#25351;&#23450;&#26816;&#26597;&#32422;&#26463;&#30340;&#23450;&#20041;&#12290;';
	$lang['strcheckadded'] = '&#26816;&#26597;&#32422;&#26463;&#24050;&#28155;&#21152;&#12290;';
	$lang['strcheckaddedbad'] = '&#26816;&#26597;&#32422;&#26463;&#28155;&#21152;&#22833;&#36133;&#12290;';
	$lang['straddpk'] = '&#28155;&#21152;&#20027;&#38190;';
	$lang['strpkneedscols'] = '&#20027;&#38190;&#33267;&#23569;&#38656;&#25351;&#23450;&#19968;&#21015;&#12290;';
	$lang['strpkadded'] = '&#20027;&#38190;&#24050;&#28155;&#21152;&#12290;';
	$lang['strpkaddedbad'] = '&#20027;&#38190;&#28155;&#21152;&#22833;&#36133;&#12290;';
	$lang['stradduniq'] = '&#28155;&#21152;&#21807;&#19968;&#38190;';
	$lang['struniqneedscols'] = '&#21807;&#19968;&#38190;&#33267;&#23569;&#38656;&#25351;&#23450;&#19968;&#21015;&#12290;';
	$lang['struniqadded'] = '&#21807;&#19968;&#38190;&#24050;&#28155;&#21152;&#12290;';
	$lang['struniqaddedbad'] = '&#21807;&#19968;&#38190;&#28155;&#21152;&#22833;&#36133;&#12290;';
	$lang['straddfk'] = '&#28155;&#21152;&#22806;&#38190;';
	$lang['strfkneedscols'] = '&#22806;&#38190;&#33267;&#23569;&#38656;&#25351;&#23450;&#19968;&#21015;&#12290;';
	$lang['strfkneedstarget'] = '&#22806;&#38190;&#38656;&#25351;&#23450;&#19968;&#20010;&#30446;&#26631;&#25968;&#25454;&#34920;&#12290;';
	$lang['strfkadded'] = '&#22806;&#38190;&#24050;&#28155;&#21152;&#12290;';
	$lang['strfkaddedbad'] = '&#22806;&#38190;&#28155;&#21152;&#22833;&#36133;&#12290;';
	$lang['strfktarget'] = '&#30446;&#26631;&#25968;&#25454;&#34920;';
	$lang['strfkcolumnlist'] = '&#38190;&#20013;&#30340;&#21015;';
	$lang['strondelete'] = 'ON DELETE';
	$lang['stronupdate'] = 'ON UPDATE';
	
	// Functions
	$lang['strfunction'] = '&#20989;&#25968;';
	$lang['strfunctions'] = '&#20989;&#25968;';
	$lang['strshowallfunctions'] = '&#26174;&#31034;&#25152;&#26377;&#20989;&#25968;';
	$lang['strnofunction'] = '&#26597;&#26080;&#27492;&#20989;&#25968;';
	$lang['strnofunctions'] = '&#26597;&#26080;&#20989;&#25968;';
	$lang['strcreateplfunction'] = '&#21019;&#24314; SQL/PL &#20989;&#25968;';
	$lang['strcreateinternalfunction'] = '&#21019;&#24314;&#20869;&#37096;&#20989;&#25968;';
	$lang['strcreatecfunction'] = '&#21019;&#24314; C &#20989;&#25968;';
	$lang['strfunctionname'] = '&#20989;&#25968;&#21517;&#31216;';
	$lang['strreturns'] = '&#36820;&#22238;';
	$lang['strproglanguage'] = '&#36807;&#31243;&#35821;&#35328;';
	$lang['strfunctionneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#20989;&#25968;&#21517;&#31216;&#12290;';
	$lang['strfunctionneedsdef'] = '&#24517;&#39035;&#25351;&#23450;&#20989;&#25968;&#23450;&#20041;&#12290;';
	$lang['strfunctioncreated'] = '&#20989;&#25968;&#24050;&#21019;&#24314;';
	$lang['strfunctioncreatedbad'] = '&#20989;&#25968;&#21019;&#24314;&#22833;&#36133;';
	$lang['strconfdropfunction'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#20989;&#25968;&quot;%s&quot;&#21527;&#65311;';
	$lang['strfunctiondropped'] = '&#20989;&#25968;&#24050;&#21024;&#38500;&#12290;';
	$lang['strfunctiondroppedbad'] = '&#20989;&#25968;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strfunctionupdated'] = '&#20989;&#25968;&#24050;&#26356;&#26032;&#12290;';
	$lang['strfunctionupdatedbad'] = '&#20989;&#25968;&#26356;&#26032;&#22833;&#36133;&#12290;';
	$lang['strobjectfile'] = '&#23545;&#35937;&#25991;&#20214;';
	$lang['strlinksymbol'] = '&#36830;&#25509;&#23545;&#35937;';
	$lang['strarguments'] = '&#21442;&#25968;';
	$lang['strargmode'] = '&#27169;&#24335;';
	$lang['strargtype'] = '&#31867;&#22411;';
	$lang['strargadd'] = '&#26032;&#28155;&#21152;&#19968;&#20010;&#21442;&#25968;';
	$lang['strargremove'] = '&#31227;&#38500;&#36825;&#20010;&#21442;&#25968;';
	$lang['strargnoargs'] = '&#35813;&#20989;&#25968;&#26080;&#21442;&#25968;&#12290;';
	$lang['strargenableargs'] = '&#20351;&#35813;&#20989;&#25968;&#30340;&#21442;&#25968;&#26377;&#25928;&#12290;';
	$lang['strargnorowabove'] = '&#22312;&#35813;&#34892;&#19978;&#38754;&#39035;&#26377;&#19968;&#34892;&#12290;';
	$lang['strargnorowbelow'] = '&#22312;&#35813;&#34892;&#19979;&#38754;&#39035;&#26377;&#19968;&#34892;&#12290;';
	$lang['strargraise'] = '&#19978;&#31227;&#12290;';
	$lang['strarglower'] = '&#19979;&#31227;&#12290;';
	$lang['strargremoveconfirm'] = '&#30830;&#23450;&#35201;&#31227;&#38500;&#36825;&#20010;&#21442;&#25968;&#21527;&#65311;&#36825;&#20010;&#25805;&#20316;&#19981;&#33021;&#25764;&#38144;&#12290;';
	$lang['strfunctioncosting'] = '&#20989;&#25968;&#20195;&#20215;(Function Costing)';
	$lang['strresultrows'] = '&#32467;&#26524;&#34892;';
	$lang['strexecutioncost'] = '&#25191;&#34892;&#20195;&#20215;';
	$lang['strspecifyfunctiontodrop'] = '&#24517;&#39035;&#33267;&#23569;&#25351;&#23450;&#19968;&#20010;&#20989;&#25968;&#26469;&#21024;&#38500;';
	
	// Triggers
	$lang['strtrigger'] = '&#35302;&#21457;&#22120;';
	$lang['strtriggers'] = '&#35302;&#21457;&#22120;';
	$lang['strshowalltriggers'] = '&#26174;&#31034;&#25152;&#26377;&#35302;&#21457;&#22120;';
	$lang['strnotrigger'] = '&#26597;&#26080;&#27492;&#35302;&#21457;&#22120;&#12290;';
	$lang['strnotriggers'] = '&#26597;&#26080;&#35302;&#21457;&#22120;&#12290;';
	$lang['strcreatetrigger'] = '&#21019;&#24314;&#35302;&#21457;&#22120;';
	$lang['strtriggerneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#35302;&#21457;&#22120;&#21517;&#31216;&#12290;';
	$lang['strtriggerneedsfunc'] = '&#24517;&#39035;&#32473;&#35302;&#21457;&#22120;&#25351;&#23450;&#19968;&#20010;&#20989;&#25968;&#12290;';
	$lang['strtriggercreated'] = '&#35302;&#21457;&#22120;&#24050;&#21019;&#24314;&#12290;';
	$lang['strtriggercreatedbad'] = '&#35302;&#21457;&#22120;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdroptrigger'] = '&#30830;&#23450;&#35201;&#23558;&#35302;&#21457;&#22120;&quot;%s&quot;&#20174;&quot;%s&quot;&#20013;&#21024;&#38500;&#21527;&#65311;';
	$lang['strconfenabletrigger'] = '&#30830;&#23450;&#35201;&#20351;&#35302;&#21457;&#22120; &quot;%s&quot; &#22312; &quot;%s&quot;&#19978;&#26377;&#25928;&#21527;?';
	$lang['strconfdisabletrigger'] = '&#30830;&#23450;&#35201;&#20351;&#35302;&#21457;&#22120; &quot;%s&quot; &#22312; &quot;%s&quot;&#19978;&#26080;&#25928;&#21527;?';
	$lang['strtriggerdropped'] = '&#35302;&#21457;&#22120;&#24050;&#21024;&#38500;&#12290;';
	$lang['strtriggerdroppedbad'] = '&#35302;&#21457;&#22120;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strtriggerenabled'] = '&#35302;&#21457;&#22120;&#24050;&#26377;&#25928;&#12290;';
	$lang['strtriggerenabledbad'] = '&#35302;&#21457;&#22120;&#26377;&#25928;&#21270;&#22833;&#36133;&#12290;';
	$lang['strtriggerdisabled'] = '&#35302;&#21457;&#22120;&#24050;&#26080;&#25928;&#12290;';
	$lang['strtriggerdisabledbad'] = '&#35302;&#21457;&#22120;&#26080;&#25928;&#21270;&#22833;&#36133;&#12290;';
	$lang['strtriggeraltered'] = '&#35302;&#21457;&#22120;&#24050;&#21464;&#26356;&#12290;';
	$lang['strtriggeralteredbad'] = '&#35302;&#21457;&#22120;&#21464;&#26356;&#22833;&#36133;&#12290;';
	$lang['strforeach'] = '&#32473;&#27599;&#19968;&#20010;';
	
	// Types
	$lang['strtype'] = '&#31867;&#22411;';
	$lang['strtypes'] = '&#31867;&#22411;';
	$lang['strshowalltypes'] = '&#26174;&#31034;&#25152;&#26377;&#30340;&#31867;&#22411;';
	$lang['strnotype'] = '&#26597;&#26080;&#27492;&#31867;&#22411;';
	$lang['strnotypes'] = '&#26597;&#26080;&#31867;&#22411;&#12290;';
	$lang['strcreatetype'] = '&#21019;&#24314;&#31867;&#22411;';
	$lang['strcreatecomptype'] = '&#21019;&#24314;&#32452;&#21512;&#31867;&#22411;';
	$lang['strcreateenumtype'] = '&#21019;&#24314;&#26522;&#20030;&#31867;&#22411;';
	$lang['strtypeneedsfield'] = '&#24517;&#39035;&#33267;&#23569;&#25351;&#23450;&#19968;&#20010;&#23383;&#27573;&#12290;';
	$lang['strtypeneedsvalue'] = '&#24517;&#39035;&#33267;&#23569;&#25351;&#23450;&#19968;&#20010;&#20540;';
	$lang['strtypeneedscols'] = '&#24517;&#39035;&#25351;&#23450;&#26377;&#25928;&#30340;&#23383;&#27573;&#25968;&#12290;';
	$lang['strtypeneedsvals'] = '&#24517;&#39035;&#25351;&#23450;&#19968;&#20010;&#26377;&#25928;&#30340;&#23383;&#27573;&#25968;&#12290;';
	$lang['strinputfn'] = '&#36755;&#20837;&#20989;&#25968;';
	$lang['stroutputfn'] = '&#36755;&#20986;&#20989;&#25968;';
	$lang['strpassbyval'] = '&#20256;&#20540;&#65311;';
	$lang['stralignment'] = '&#21442;&#25968;';
	$lang['strelement'] = '&#20803;&#32032;';
	$lang['strdelimiter'] = '&#20998;&#38548;&#31526;';
	$lang['strstorage'] = '&#30913;&#30424;&#23384;&#20648;';
	$lang['strfield'] = '&#23383;&#27573;';
	$lang['strvalue'] = '&#20540;';
	$lang['strnumfields'] = '&#21015;&#25968;';
	$lang['strnumvalues'] = '&#20540;&#25968;';
	$lang['strtypeneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#31867;&#22411;&#21517;&#31216;&#12290;';
	$lang['strtypeneedslen'] = '&#24517;&#39035;&#25351;&#23450;&#31867;&#22411;&#38271;&#24230;&#12290;';
	$lang['strtypecreated'] = '&#31867;&#22411;&#24050;&#21019;&#24314;&#12290;';
	$lang['strtypecreatedbad'] = '&#31867;&#22411;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdroptype'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&quot;%s&quot;&#31867;&#22411;&#21527;&#65311;';
	$lang['strtypedropped'] = '&#31867;&#22411;&#24050;&#21024;&#38500;&#12290;';
	$lang['strtypedroppedbad'] = '&#31867;&#22411;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strflavor'] = '&#39118;&#26684;&#65288;Flavor&#65289;';
	$lang['strbasetype'] = '&#22522;&#26412;';
	$lang['strcompositetype'] = '&#32452;&#21512;';
	$lang['strpseudotype'] = '&#20266;&#65288;Pseudo&#65289;';
	$lang['strenum'] = 'Enum';
	$lang['strenumvalues'] = '&#26522;&#20030;&#31867;&#22411;';
	
	// Schemas
	$lang['strschema'] = '&#27169;&#24335;';
	$lang['strschemas'] = '&#27169;&#24335;';
	$lang['strshowallschemas'] = '&#26174;&#31034;&#25152;&#26377;&#27169;&#24335;';
	$lang['strnoschema'] = '&#26597;&#26080;&#27492;&#27169;&#24335;';
	$lang['strnoschemas'] = '&#26597;&#26080;&#27169;&#24335;';
	$lang['strcreateschema'] = '&#21019;&#24314;&#27169;&#24335;';
	$lang['strschemaname'] = '&#27169;&#24335;&#21517;&#31216;';
	$lang['strschemaneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#27169;&#24335;&#21517;&#31216;';
	$lang['strschemacreated'] = '&#27169;&#24335;&#24050;&#21019;&#24314;';
	$lang['strschemacreatedbad'] = '&#27169;&#24335;&#21019;&#24314;&#22833;&#36133;';
	$lang['strconfdropschema'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#27169;&#24335;&quot;%s&quot;&#21527;&#65311;';
	$lang['strschemadropped'] = '&#27169;&#24335;&#24050;&#21024;&#38500;';
	$lang['strschemadroppedbad'] = '&#27169;&#24335;&#21024;&#38500;&#22833;&#36133;';
	$lang['strschemaaltered'] = '&#27169;&#24335;&#24050;&#21464;&#26356;&#12290;';
	$lang['strschemaalteredbad'] = '&#27169;&#24335;&#21464;&#26356;&#22833;&#36133;&#12290;';
	$lang['strsearchpath'] = '&#27169;&#24335;&#26597;&#25214;&#36335;&#24452;';
	$lang['strspecifyschematodrop'] = '&#24517;&#39035;&#33267;&#23569;&#25351;&#23450;&#19968;&#20010;&#27169;&#24335;&#26469;&#21024;&#38500;';
	
	// Reports
	$lang['strreport'] = '&#25253;&#34920;';
	$lang['strreports'] = '&#25253;&#34920;';
	$lang['strshowallreports'] = '&#26174;&#31034;&#25152;&#26377;&#25253;&#34920;';
	$lang['strnoreports'] = '&#26597;&#26080;&#25253;&#34920;&#12290;';
	$lang['strcreatereport'] = '&#21019;&#24314;&#25253;&#34920;';
	$lang['strreportdropped'] = '&#25253;&#34920;&#24050;&#21024;&#38500;&#12290;';
	$lang['strreportdroppedbad'] = '&#25253;&#34920;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strconfdropreport'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#25253;&#34920;&quot;%s&quot;&#21527;&#65311;';
	$lang['strreportneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#25253;&#34920;&#21517;&#31216;&#12290;';
	$lang['strreportneedsdef'] = '&#24517;&#39035;&#32473;&#25253;&#34920;&#25351;&#23450;SQL&#12290;';
	$lang['strreportcreated'] = '&#25253;&#34920;&#24050;&#20445;&#23384;&#12290;';
	$lang['strreportcreatedbad'] = '&#25253;&#34920;&#20445;&#23384;&#22833;&#36133;&#12290;';
	
	// Domains
	$lang['strdomain'] = '&#22495;';
	$lang['strdomains'] = '&#22495;';
	$lang['strshowalldomains'] = '&#26174;&#31034;&#25152;&#26377;&#22495;';
	$lang['strnodomains'] = '&#26597;&#26080; &#22495;&#12290;';
	$lang['strcreatedomain'] = '&#21019;&#24314;&#22495;';
	$lang['strdomaindropped'] = '&#22495;&#24050;&#21024;&#38500;&#12290;';
	$lang['strdomaindroppedbad'] = '&#22495;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strconfdropdomain'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#22495; &quot;%s&quot;&#21527;?';
	$lang['strdomainneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#22495;&#21517;&#31216;&#12290;';
	$lang['strdomaincreated'] = '&#22495;&#24050;&#21019;&#24314;&#12290;';
	$lang['strdomaincreatedbad'] = '&#22495;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strdomainaltered'] = '&#22495;&#24050;&#21464;&#26356;&#12290;';
	$lang['strdomainalteredbad'] = '&#22495;&#21464;&#26356;&#22833;&#36133;&#12290;';
	
	// Operators
	$lang['stroperator'] = '&#25805;&#20316;&#31526;';
	$lang['stroperators'] = '&#25805;&#20316;&#31526;';
	$lang['strshowalloperators'] = '&#26174;&#31034;&#25152;&#26377;&#25805;&#20316;&#31526;';
	$lang['strnooperator'] = '&#26597;&#26080;&#27492;&#25805;&#20316;&#31526;&#12290;';
	$lang['strnooperators'] = '&#26597;&#26080;&#25805;&#20316;&#31526;&#12290;';
	$lang['strcreateoperator'] = '&#21019;&#24314;&#25805;&#20316;&#31526;';
	$lang['strleftarg'] = '&#24038;&#21442;&#25968;&#31867;&#22411;';
	$lang['strrightarg'] = '&#21491;&#21442;&#25968;&#31867;&#22411;';
	$lang['strcommutator'] = '&#36716;&#25442;&#31526;';
	$lang['strnegator'] = '&#38750;&#25805;&#20316;&#31526;';
	$lang['strrestrict'] = '&#21463;&#38480;';
	$lang['strjoin'] = '&#36830;&#25509;';
	$lang['strhashes'] = '&#21704;&#24076;';
	$lang['strmerges'] = '&#21512;&#24182;';
	$lang['strleftsort'] = '&#24038;&#25490;&#24207;';
	$lang['strrightsort'] = '&#21491;&#25490;&#24207;';
	$lang['strlessthan'] = '&#23567;&#20110;';
	$lang['strgreaterthan'] = '&#22823;&#20110;';
	$lang['stroperatorneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#25805;&#20316;&#31526;&#21517;&#31216;&#12290;';
	$lang['stroperatorcreated'] = '&#25805;&#20316;&#31526;&#24050;&#21019;&#24314;';
	$lang['stroperatorcreatedbad'] = '&#25805;&#20316;&#31526;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdropoperator'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#25805;&#20316;&#31526; &quot;%s&quot;&#21527;?';
	$lang['stroperatordropped'] = '&#25805;&#20316;&#31526;&#24050;&#21024;&#38500;&#12290;';
	$lang['stroperatordroppedbad'] = '&#25805;&#20316;&#31526;&#21024;&#38500;&#22833;&#36133;&#12290;';
	
	// Casts
	$lang['strcasts'] = '&#31867;&#22411;&#36716;&#25442;';
	$lang['strnocasts'] = '&#26597;&#26080;&#31867;&#22411;&#36716;&#25442;&#12290;';
	$lang['strsourcetype'] = '&#28304;&#31867;&#22411;';
	$lang['strtargettype'] = '&#30446;&#26631;&#31867;&#22411;';
	$lang['strimplicit'] = '&#38544;&#21547;&#30340;';
	$lang['strinassignment'] = '&#22996;&#27966;&#20013;';
	$lang['strbinarycompat'] = '(&#20108;&#36827;&#21046;&#20860;&#23481;)';
	
	// Conversions
	$lang['strconversions'] = '&#32534;&#30721;&#36716;&#25442;';
	$lang['strnoconversions'] = '&#26597;&#26080;&#32534;&#30721;&#36716;&#25442;&#12290;';
	$lang['strsourceencoding'] = '&#28304;&#32534;&#30721;';
	$lang['strtargetencoding'] = '&#30446;&#26631;&#32534;&#30721;';
	
	// Languages
	$lang['strlanguages'] = '&#36807;&#31243;&#35821;&#35328;';
	$lang['strnolanguages'] = '&#26597;&#26080;&#36807;&#31243;&#35821;&#35328;&#12290;';
	$lang['strtrusted'] = '&#20449;&#20219;&#30340;';
	
	// Info
	$lang['strnoinfo'] = '&#26080;&#36164;&#26009;&#65288;information&#65289;&#21487;&#29992;&#12290;';
	$lang['strreferringtables'] = '&#26597;&#35810;&#65288;Referring&#65289;&#34920;';
	$lang['strparenttables'] = '&#29238;&#34920;';
	$lang['strchildtables'] = '&#23376;&#34920;';
	
	// Aggregates
	$lang['straggregate'] = '&#32858;&#38598;';
	$lang['straggregates'] = '&#32858;&#38598;';
	$lang['strnoaggregates'] = '&#26597;&#26080;&#32858;&#38598;&#12290;';
	$lang['stralltypes'] = '(&#25152;&#26377;&#31867;&#22411;)';
	$lang['strcreateaggregate'] = '&#21019;&#24314;&#32858;&#38598;';
	$lang['straggrbasetype'] = '&#36755;&#20837;&#25968;&#25454;&#31867;&#22411;';
	$lang['straggrsfunc'] = '&#29366;&#24577;&#36716;&#21270;&#20989;&#25968;';
	$lang['straggrstype'] = '&#29366;&#24577;&#31867;&#22411;';
	$lang['straggrffunc'] = '&#26368;&#32456;&#20989;&#25968;';
	$lang['straggrinitcond'] = '&#21021;&#22987;&#20989;&#25968;';
	$lang['straggrsortop'] = '&#25490;&#24207;&#25805;&#20316;&#31526;';
	$lang['strconfdropaggregate'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#32858;&#38598; &quot;%s&quot;&#21527;?';
	$lang['straggregatedropped'] = '&#32858;&#38598;&#24050;&#21024;&#38500;&#12290;';
	$lang['straggregatedroppedbad'] = '&#32858;&#38598;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['straggraltered'] = '&#32858;&#38598;&#24050;&#21464;&#26356;&#12290;';
	$lang['straggralteredbad'] = '&#32858;&#38598;&#21464;&#26356;&#22833;&#36133;&#12290;';
	$lang['straggrneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#32858;&#38598;&#30340;&#21517;&#31216;';
	$lang['straggrneedsbasetype'] = '&#24517;&#39035;&#25351;&#23450;&#32858;&#38598;&#30340;&#36755;&#20837;&#25968;&#25454;&#31867;&#22411;';
	$lang['straggrneedssfunc'] = '&#24517;&#39035;&#25351;&#23450;&#32858;&#38598;&#30340;&#29366;&#24577;&#36716;&#25442;&#20989;&#25968;';
	$lang['straggrneedsstype'] = '&#24517;&#39035;&#25351;&#23450;&#32858;&#38598;&#30340;&#29366;&#24577;&#20540;&#30340;&#25968;&#25454;&#31867;&#22411;';
	$lang['straggrcreated'] = '&#32858;&#38598;&#24050;&#21019;&#24314;&#12290;';
	$lang['straggrcreatedbad'] = '&#32858;&#38598;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['straggrshowall'] = '&#26174;&#31034;&#25152;&#26377;&#32858;&#38598;';
	
	// Operator Classes
	$lang['stropclasses'] = '&#25805;&#20316;&#31526;&#31867;';
	$lang['strnoopclasses'] = '&#26597;&#26080;&#27492;&#25805;&#20316;&#31526;&#31867;&#12290;';
	$lang['straccessmethod'] = '&#23384;&#21462;&#26041;&#27861;';
	
	// Stats and performance
	$lang['strrowperf'] = '&#34892;&#24615;&#33021;';
	$lang['strioperf'] = 'I/O &#24615;&#33021;';
	$lang['stridxrowperf'] = '&#32034;&#24341;&#34892;&#24615;&#33021;';
	$lang['stridxioperf'] = '&#32034;&#24341; I/O &#24615;&#33021;';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = '&#39034;&#24207;&#25195;&#25551;';
	$lang['strscan'] = '&#25195;&#25551;';
	$lang['strread'] = '&#35835;&#21462;';
	$lang['strfetch'] = '&#21462;&#24471;';
	$lang['strheap'] = '&#22534;';
	$lang['strtoast'] = 'TOAST';
	$lang['strtoastindex'] = 'TOAST &#32034;&#24341;';
	$lang['strcache'] = '&#32531;&#23384;';
	$lang['strdisk'] = '&#30828;&#30424;';
	$lang['strrows2'] = '&#34892;';
	
	// Tablespaces
	$lang['strtablespace'] = '&#34920;&#31354;&#38388;';
	$lang['strtablespaces'] = '&#34920;&#31354;&#38388;';
	$lang['strshowalltablespaces'] = '&#26174;&#31034;&#25152;&#26377;&#34920;&#31354;&#38388;';
	$lang['strnotablespaces'] = '&#26597;&#26080;&#27492;&#34920;&#31354;&#38388;&#12290;';
	$lang['strcreatetablespace'] = '&#21019;&#24314;&#34920;&#31354;&#38388;';
	$lang['strlocation'] = '&#20301;&#32622;';
	$lang['strtablespaceneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#34920;&#31354;&#38388;&#21517;&#31216;&#12290;';
	$lang['strtablespaceneedsloc'] = '&#24517;&#39035;&#25351;&#23450;&#21019;&#24314;&#34920;&#31354;&#38388;&#30340;&#25991;&#20214;&#22841;&#12290;';
	$lang['strtablespacecreated'] = '&#34920;&#31354;&#38388;&#24050;&#21019;&#24314;&#12290;';
	$lang['strtablespacecreatedbad'] = '&#34920;&#31354;&#38388;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdroptablespace'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#34920;&#31354;&#38388; &quot;%s&quot;&#21527;?';
	$lang['strtablespacedropped'] = '&#34920;&#31354;&#38388;&#24050;&#21024;&#38500;&#12290;';
	$lang['strtablespacedroppedbad'] = '&#34920;&#31354;&#38388;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strtablespacealtered'] = '&#34920;&#31354;&#38388;&#24050;&#21464;&#26356;&#12290;';
	$lang['strtablespacealteredbad'] = '&#34920;&#31354;&#38388;&#21464;&#26356;&#22833;&#36133;&#12290;';
	
	// Slony clusters
	$lang['strcluster'] = '&#38598;&#32676;';
	$lang['strnoclusters'] = '&#26597;&#26080;&#27492;&#38598;&#32676;&#12290;';
	$lang['strconfdropcluster'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#38598;&#32676; &quot;%s&quot;&#21527;?';
	$lang['strclusterdropped'] = '&#38598;&#32676;&#24050;&#21024;&#38500;&#12290;';
	$lang['strclusterdroppedbad'] = '&#38598;&#32676;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strinitcluster'] = '&#21021;&#22987;&#21270;&#38598;&#32676;';
	$lang['strclustercreated'] = '&#38598;&#32676;&#24050;&#21021;&#22987;&#21270;&#12290;';
	$lang['strclustercreatedbad'] = '&#38598;&#32676;&#21021;&#22987;&#21270;&#22833;&#36133;&#12290;';
	$lang['strclusterneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#38598;&#32676;&#21517;&#31216;&#12290;';
	$lang['strclusterneedsnodeid'] = '&#24517;&#39035;&#25351;&#23450;&#26412;&#22320;&#33410;&#28857;ID&#12290;';
	
	// Slony nodes
	$lang['strnodes'] = '&#33410;&#28857;';
	$lang['strnonodes'] = '&#26597;&#26080;&#33410;&#28857;&#12290;';
	$lang['strcreatenode'] = '&#21019;&#24314;&#33410;&#28857;';
	$lang['strid'] = 'ID';
	$lang['stractive'] = '&#27963;&#21160;&#30340;';
	$lang['strnodecreated'] = '&#33410;&#28857;&#24050;&#21019;&#24314;&#12290;';
	$lang['strnodecreatedbad'] = '&#33410;&#28857;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdropnode'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#33410;&#28857; &quot;%s&quot;&#21527;?';
	$lang['strnodedropped'] = '&#33410;&#28857;&#24050;&#21024;&#38500;&#12290;';
	$lang['strnodedroppedbad'] = '&#33410;&#28857;&#21024;&#38500;&#22833;&#36133;';
	$lang['strfailover'] = '&#25925;&#38556;&#20999;&#25442;';
	$lang['strnodefailedover'] = '&#33410;&#28857;&#24050;&#25925;&#38556;&#20999;&#25442;&#12290;';
	$lang['strnodefailedoverbad'] = '&#33410;&#28857;&#25925;&#38556;&#20999;&#25442;&#22833;&#36133;&#12290;';
	$lang['strstatus'] = '&#29366;&#24577;';
	$lang['strhealthy'] = '&#20581;&#24247;&#24230;';
	$lang['stroutofsync'] = '&#21516;&#27493;&#36807;&#26399;';
	$lang['strunknown'] = '&#26410;&#30693;&#30340;';
	
	// Slony paths
	$lang['strpaths'] = '&#36335;&#24452;';
	$lang['strnopaths'] = '&#26597;&#26080;&#36335;&#24452;&#12290;';
	$lang['strcreatepath'] = '&#21019;&#24314;&#36335;&#24452;';
	$lang['strnodename'] = '&#33410;&#28857;&#21517;&#31216;';
	$lang['strnodeid'] = '&#33410;&#28857; ID';
	$lang['strconninfo'] = '&#36830;&#25509;&#23383;&#31526;&#20018;';
	$lang['strconnretry'] = '&#37325;&#35797;&#36830;&#25509;&#38388;&#38548;&#26102;&#38388;';
	$lang['strpathneedsconninfo'] = '&#24517;&#39035;&#25351;&#23450;&#36335;&#24452;&#30340;&#36830;&#25509;&#23383;&#31526;&#20018;&#12290;';
	$lang['strpathneedsconnretry'] = '&#24517;&#39035;&#25351;&#23450;&#37325;&#35797;&#36830;&#25509;&#38388;&#38548;&#26102;&#38388;&#12290;';
	$lang['strpathcreated'] = '&#36335;&#24452;&#24050;&#21019;&#24314;&#12290;';
	$lang['strpathcreatedbad'] = '&#36335;&#24452;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdroppath'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#36335;&#24452; &quot;%s&quot;&#21527;?';
	$lang['strpathdropped'] = '&#36335;&#24452;&#24050;&#21024;&#38500;&#12290;';
	$lang['strpathdroppedbad'] = '&#36335;&#24452;&#21024;&#38500;&#22833;&#36133;&#12290;';
	
	// Slony listens
	$lang['strlistens'] = '&#30417;&#21548;';
	$lang['strnolistens'] = '&#26597;&#26080;&#30417;&#21548;&#12290;';
	$lang['strcreatelisten'] = '&#21019;&#24314;&#30417;&#21548;';
	$lang['strlistencreated'] = '&#30417;&#21548;&#24050;&#21019;&#24314;&#12290;';
	$lang['strlistencreatedbad'] = '&#30417;&#21548;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdroplisten'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#30417;&#21548; &quot;%s&quot;&#21527;?';
	$lang['strlistendropped'] = '&#30417;&#21548;&#24050;&#21024;&#38500;&#12290;';
	$lang['strlistendroppedbad'] = '&#30417;&#21548;&#21024;&#38500;&#22833;&#36133;&#12290;';
	
	// Slony replication sets
	$lang['strrepsets'] = '&#22797;&#20889;&#32676;&#32452;';
	$lang['strnorepsets'] = '&#26597;&#26080;&#22797;&#20889;&#32676;&#32452;&#12290;';
	$lang['strcreaterepset'] = '&#21019;&#24314;&#22797;&#20889;&#32676;&#32452;';
	$lang['strrepsetcreated'] = '&#22797;&#20889;&#32676;&#32452;&#24050;&#21019;&#24314;&#12290;';
	$lang['strrepsetcreatedbad'] = '&#22797;&#20889;&#32676;&#32452;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strconfdroprepset'] = '&#30830;&#23450;&#35201;&#21024;&#38500;&#22797;&#20889;&#32676;&#32452; &quot;%s&quot;&#21527;?';
	$lang['strrepsetdropped'] = '&#22797;&#20889;&#32676;&#32452;&#24050;&#21024;&#38500;&#12290;';
	$lang['strrepsetdroppedbad'] = '&#22797;&#20889;&#32676;&#32452;&#21024;&#38500;&#22833;&#36133;&#12290;';
	$lang['strmerge'] = '&#21512;&#24182;';
	$lang['strmergeinto'] = '&#21512;&#24182;&#36827;';
	$lang['strrepsetmerged'] = '&#22797;&#20889;&#32676;&#32452;&#24050;&#21512;&#24182;&#12290;';
	$lang['strrepsetmergedbad'] = '&#22797;&#20889;&#32676;&#32452;&#21512;&#24182;&#22833;&#36133;&#12290;';
	$lang['strmove'] = '&#31227;&#21160;';
	$lang['strneworigin'] = '&#26032;&#24314;&#21021;&#22987;&#28857;';
	$lang['strrepsetmoved'] = '&#22797;&#20889;&#32676;&#32452;&#24050;&#31227;&#21160;&#12290;';
	$lang['strrepsetmovedbad'] = '&#22797;&#20889;&#32676;&#32452;&#31227;&#21160;&#22833;&#36133;&#12290;';
	$lang['strnewrepset'] = '&#26032;&#24314;&#20214;&#22797;&#20889;&#32676;&#32452;';
	$lang['strlock'] = '&#38145;&#23450;';
	$lang['strlocked'] = '&#24050;&#38145;&#23450;';
	$lang['strunlock'] = '&#35299;&#38145;';
	$lang['strconflockrepset'] = '&#30830;&#23450;&#35201;&#38145;&#23450;&#22797;&#20889;&#32676;&#32452; &quot;%s&quot;&#21527;?';
	$lang['strrepsetlocked'] = '&#22797;&#20889;&#32676;&#32452;&#24050;&#38145;&#23450;&#12290;';
	$lang['strrepsetlockedbad'] = '&#22797;&#20889;&#32676;&#32452;&#38145;&#23450;&#22833;&#36133;&#12290;';
	$lang['strconfunlockrepset'] = '&#30830;&#23450;&#35201;&#35299;&#38145;&#22797;&#20889;&#32676;&#32452; &quot;%s&quot;&#21527;?';
	$lang['strrepsetunlocked'] = '&#22797;&#20889;&#32676;&#32452;&#24050;&#35299;&#38145;&#12290;';
	$lang['strrepsetunlockedbad'] = '&#22797;&#20889;&#32676;&#32452;&#35299;&#38145;&#22833;&#36133;&#12290;';
	$lang['stronlyonnode'] = '&#20165;&#19968;&#20010;&#33410;&#28857;';
	$lang['strddlscript'] = 'DDL &#33050;&#26412;';
	$lang['strscriptneedsbody'] = '&#24517;&#39035;&#22312;&#25152;&#26377;&#33410;&#28857;&#19978;&#25191;&#34892;&#35813;&#33050;&#26412;&#12290;';
	$lang['strscriptexecuted'] = '&#22797;&#20889;&#32676;&#32452; DDL &#33050;&#26412;&#24050;&#25191;&#34892;&#12290;';
	$lang['strscriptexecutedbad'] = '&#22797;&#20889;&#32676;&#32452; DDL &#33050;&#26412;&#25191;&#34892;&#22833;&#36133;&#12290;';
	$lang['strtabletriggerstoretain'] = '&#20197;&#19979;&#35302;&#21457;&#22120;&#23558;&#19981;&#20250;&#34987;Slony&#31105;&#29992;:';
	
	// Slony tables in replication sets
	$lang['straddtable'] = '&#28155;&#21152;&#34920;';
	$lang['strtableneedsuniquekey'] = '&#35201;&#28155;&#21152;&#30340;&#34920;&#38656;&#35201;&#25351;&#23450;&#20027;&#38190;&#25110;&#32773;&#21807;&#19968;&#38190;&#12290;';
	$lang['strtableaddedtorepset'] = '&#34920;&#24050;&#28155;&#21152;&#21040;&#22797;&#20889;&#32676;&#32452;&#12290;';
	$lang['strtableaddedtorepsetbad'] = '&#34920;&#28155;&#21152;&#21040;&#22797;&#20889;&#32676;&#32452;&#22833;&#36133;&#12290;';
	$lang['strconfremovetablefromrepset'] = '&#30830;&#23450;&#35201;&#23558;&#34920; &quot;%s&quot; &#20174;&#22797;&#20889;&#32676;&#32452; &quot;%s&quot;&#20013;&#21024;&#38500;&#21527;?';
	$lang['strtableremovedfromrepset'] = '&#34920;&#24050;&#20174;&#22797;&#20889;&#32676;&#32452;&#20013;&#21024;&#38500;&#12290;';
	$lang['strtableremovedfromrepsetbad'] = '&#34920;&#20174;&#22797;&#20889;&#32676;&#32452;&#20013;&#21024;&#38500;&#22833;&#36133;';
	
	// Slony sequences in replication sets
	$lang['straddsequence'] = '&#28155;&#21152;&#24207;&#21015;';
	$lang['strsequenceaddedtorepset'] = '&#24207;&#21015;&#24050;&#28155;&#21152;&#21040;&#22797;&#20889;&#32676;&#32452;&#12290;';
	$lang['strsequenceaddedtorepsetbad'] = '&#24207;&#21015;&#28155;&#21152;&#21040;&#22797;&#20889;&#32676;&#32452;&#22833;&#36133;&#12290;';
	$lang['strconfremovesequencefromrepset'] = '&#30830;&#23450;&#35201;&#23558;&#24207;&#21015; &quot;%s&quot; &#20174;&#22797;&#20889;&#32676;&#32452; &quot;%s&quot;&#20013;&#21024;&#38500;&#21527;?';
	$lang['strsequenceremovedfromrepset'] = '&#24207;&#21015;&#24050;&#20174;&#22797;&#20889;&#32676;&#32452;&#20013;&#21024;&#38500;&#12290;';
	$lang['strsequenceremovedfromrepsetbad'] = '&#24207;&#21015;&#20174;&#22797;&#20889;&#32676;&#32452;&#20013;&#21024;&#38500;&#22833;&#36133;&#12290;';
	
	// Slony subscriptions
	$lang['strsubscriptions'] = '&#35746;&#38405;';
	$lang['strnosubscriptions'] = '&#26597;&#26080;&#35746;&#38405;&#12290;';
	
	// Miscellaneous
	$lang['strtopbar'] = '%s &#26550;&#20110; %s&#65306;%s &#65293; &#24744;&#26159; &quot;%s&quot;';
	$lang['strtimefmt'] = 'jS M, Y g:iA';
	$lang['strhelp'] = '&#24110;&#21161;';
	$lang['strhelpicon'] = '?';
	$lang['strhelppagebrowser'] = '&#24110;&#21161;&#39029;&#38754;&#27983;&#35272;';
	$lang['strselecthelppage'] = '&#36873;&#25321;&#19968;&#20010;&#24110;&#21161;&#39029;&#38754;';
	$lang['strinvalidhelppage'] = '&#26080;&#25928;&#30340;&#24110;&#21161;&#39029;&#38754;&#12290;';
	$lang['strlogintitle'] = '&#30331;&#20837; %s';
	$lang['strlogoutmsg'] = '&#27880;&#38144; %s';
	$lang['strloading'] = '&#21152;&#36733;&#20013;&#12290;&#12290;&#12290;';
	$lang['strerrorloading'] = '&#21152;&#36733;&#38169;&#35823;';
	$lang['strclicktoreload'] = '&#28857;&#20987;&#37325;&#26032;&#21152;&#36733;';
	
	// Autovacuum
	$lang['strautovacuum'] = '&#33258;&#21160;&#28165;&#29702;(Autovacuum)';
	$lang['strturnedon'] = '&#25171;&#24320;';
	$lang['strturnedoff'] = '&#20851;&#38381;';
	$lang['strenabled'] = '&#26377;&#25928;';
	$lang['strvacuumbasethreshold'] = '&#28165;&#29702;&#22522;&#26412;&#20020;&#30028;&#20540;';
	$lang['strvacuumscalefactor'] = '&#28165;&#29702;&#25442;&#31639;&#31995;&#25968;';
	$lang['stranalybasethreshold'] = '&#20998;&#26512;&#22522;&#26412;&#20020;&#30028;&#20540;';
	$lang['stranalyzescalefactor'] = '&#20998;&#26512;&#25442;&#31639;&#31995;&#25968;';
	$lang['strvacuumcostdelay'] = '&#28165;&#29702;&#25104;&#26412;&#24310;&#36831;';
	$lang['strvacuumcostlimit'] = '&#28165;&#29702;&#25104;&#26412;&#38480;&#21046;';
	
	// Table-level Locks
	$lang['strlocks'] = '&#38145;';
	$lang['strtransaction'] = '&#20107;&#21153;ID';
	$lang['strvirtualtransaction'] = '&#34394;&#25311;&#20107;&#21153;ID';
	$lang['strprocessid'] = '&#36827;&#31243;ID';
	$lang['strmode'] = '&#38145;&#23450;&#27169;&#24335;';
	$lang['strislockheld'] = '&#25317;&#26377;&#38145;?';
	
	// Prepared transactions
	$lang['strpreparedxacts'] = '&#24050;&#20934;&#22791;&#20107;&#21153;';
	$lang['strxactid'] = '&#20107;&#21153;ID';
	$lang['strgid'] = '&#20840;&#22495;ID';
	
	// Fulltext search
	$lang['strfulltext'] = '&#20840;&#25991;&#26816;&#32034;';
	$lang['strftsconfig'] = '&#20840;&#25991;&#26816;&#32034;&#37197;&#32622;';
	$lang['strftsconfigs'] = '&#37197;&#32622;';
	$lang['strftscreateconfig'] = '&#21019;&#24314; &#20840;&#25991;&#26816;&#32034;&#37197;&#32622;';
	$lang['strftscreatedict'] = '&#21019;&#24314;&#23383;&#20856;';
	$lang['strftscreatedicttemplate'] = '&#21019;&#24314;&#23383;&#20856;&#27169;&#26495;';
	$lang['strftscreateparser'] = '&#21019;&#24314;&#20998;&#26512;&#22120;';
	$lang['strftsnoconfigs'] = '&#27809;&#26377;&#25214;&#21040;&#20840;&#25991;&#26816;&#32034;&#37197;&#32622;&#12290;';
	$lang['strftsconfigdropped'] = '&#20840;&#25991;&#26816;&#32034;&#37197;&#32622;&#24050;&#31227;&#38500;&#12290;';
	$lang['strftsconfigdroppedbad'] = '&#20840;&#25991;&#26816;&#32034;&#31227;&#38500;&#22833;&#36133;&#12290;';
	$lang['strconfdropftsconfig'] = '&#30830;&#23450;&#35201;&#31227;&#38500;&#20840;&#25991;&#26816;&#32034;&#26816;&#32034;&#37197;&#32622; &quot;%s&quot;&#21527;?';
	$lang['strconfdropftsdict'] = '&#30830;&#23450;&#35201;&#31227;&#38500;&#20840;&#25991;&#26816;&#32034;&#23383;&#20856; &quot;%s&quot;&#21527;?';
	$lang['strconfdropftsmapping'] = '&#30830;&#23450;&#35201;&#23558;&#26144;&#23556; &quot;%s&quot; &#20174;&#20840;&#25991;&#26816;&#32034;&#37197;&#32622; &quot;%s&quot;&#20013;&#31227;&#38500;&#21527;?';
	$lang['strftstemplate'] = '&#27169;&#26495;';
	$lang['strftsparser'] = '&#20998;&#26512;&#22120;';
	$lang['strftsconfigneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#20840;&#25991;&#26816;&#32034;&#37197;&#32622;&#21517;&#31216;&#12290;';
	$lang['strftsconfigcreated'] = '&#20840;&#25991;&#26816;&#32034;&#37197;&#32622;&#24050;&#21019;&#24314;';
	$lang['strftsconfigcreatedbad'] = '&#20840;&#25991;&#26816;&#32034;&#37197;&#32622;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strftsmapping'] = '&#26144;&#23556;';
	$lang['strftsdicts'] = '&#23383;&#20856;';
	$lang['strftsdict'] = '&#23383;&#20856;';
	$lang['strftsemptymap'] = '&#31354;&#30340;&#20840;&#25991;&#26816;&#32034;&#37197;&#32622;&#26144;&#23556;&#12290;';
	$lang['strftswithmap'] = '&#38468;&#24102;&#26144;&#23556;&#65288;With map&#65289;';
	$lang['strftsmakedefault'] = '&#20026;&#26412;&#22320;&#21270;&#20316;&#25104;&#40664;&#35748;&#20540;';
	$lang['strftsconfigaltered'] = '&#20840;&#25991;&#26816;&#32034;&#24050;&#21464;&#26356;&#12290;';
	$lang['strftsconfigalteredbad'] = '&#20840;&#25991;&#26816;&#32034;&#21464;&#26356;&#22833;&#36133;&#12290;';
	$lang['strftsconfigmap'] = '&#20840;&#25991;&#26816;&#32034;&#37197;&#32622;&#26144;&#23556;';
	$lang['strftsparsers'] = '&#20840;&#25991;&#26816;&#32034;&#20998;&#26512;&#22120;';
	$lang['strftsnoparsers'] = '&#26080; &#26377;&#25928;&#30340;&#20840;&#25991;&#26816;&#32034;&#20998;&#26512;&#22120;&#12290;';
	$lang['strftsnodicts'] = '&#26080; &#26377;&#25928;&#30340;&#20840;&#25991;&#26816;&#32034;&#23383;&#20856;&#12290;';
	$lang['strftsdictcreated'] = '&#20840;&#25991;&#26816;&#32034;&#23383;&#20856;&#24050;&#21019;&#24314;';
	$lang['strftsdictcreatedbad'] = '&#20840;&#25991;&#26816;&#32034;&#23383;&#20856;&#21019;&#24314;&#22833;&#36133;&#12290;';
	$lang['strftslexize'] = 'Lexize';
	$lang['strftsinit'] = '&#21021;&#22987;&#21270;';
	$lang['strftsoptionsvalues'] = '&#36873;&#39033;&#21644;&#20540;';
	$lang['strftsdictneedsname'] = '&#24517;&#39035;&#25351;&#23450;&#20840;&#25991;&#26816;&#32034;&#23383;&#20856;&#21517;&#31216;&#12290;';
	$lang['strftsdictdropped'] = '&#20840;&#25991;&#26816;&#32034;&#23383;&#20856;&#24050;&#31227;&#38500;&#12290;';
	$lang['strftsdictdroppedbad'] = '&#20840;&#25991;&#26816;&#32034;&#23383;&#20856;&#31227;&#38500;&#22833;&#36133;&#12290;';
	$lang['strftsdictaltered'] = '&#20840;&#25991;&#26816;&#32034;&#23383;&#20856;&#24050;&#21464;&#26356;&#12290;';
	$lang['strftsdictalteredbad'] = '&#20840;&#25991;&#26816;&#32034;&#23383;&#20856;&#21464;&#26356;&#22833;&#36133;&#12290;';
	$lang['strftsaddmapping'] = '&#28155;&#21152;&#26144;&#23556;';
	$lang['strftsspecifymappingtodrop'] = '&#24517;&#39035;&#26368;&#23569;&#25351;&#23450;&#19968;&#20010;&#26144;&#23556;&#26469;&#31227;&#38500;';
	$lang['strftsspecifyconfigtoalter'] = '&#24517;&#39035;&#25351;&#23450;&#19968;&#20010;&#20840;&#25991;&#26816;&#32034;&#37197;&#32622;&#26469;&#21464;&#26356;';
	$lang['strftsmappingdropped'] = '&#20840;&#25991;&#26816;&#32034;&#26144;&#23556;&#24050;&#21024;&#38500;&#12290;';
	$lang['strftsmappingdroppedbad'] = '&#20840;&#25991;&#26816;&#32034;&#26144;&#23556;&#31227;&#38500;&#22833;&#36133;&#12290;';
	$lang['strftsnodictionaries'] = '&#26597;&#26080;&#23383;&#20856;&#12290;';
	$lang['strftsmappingaltered'] = '&#20840;&#25991;&#26816;&#32034;&#26144;&#23556;&#24050;&#21464;&#26356;&#12290;';
	$lang['strftsmappingalteredbad'] = '&#20840;&#25991;&#26816;&#32034;&#26144;&#23556;&#21464;&#26356;&#22833;&#36133;&#12290;';
	$lang['strftsmappingadded'] = '&#20840;&#25991;&#26816;&#32034;&#26144;&#23556;&#24050;&#28155;&#21152;&#12290;';
	$lang['strftsmappingaddedbad'] = '&#20840;&#25991;&#26816;&#32034;&#26144;&#23556;&#28155;&#21152;&#22833;&#36133;&#12290;';
	$lang['strftsmappingdropped'] = '&#20840;&#25991;&#26816;&#32034;&#26144;&#23556;&#24050;&#21024;&#38500;&#12290;';
	$lang['strftsmappingdroppedbad'] = '&#20840;&#25991;&#26816;&#32034;&#26144;&#23556;&#31227;&#38500;&#22833;&#36133;&#12290;';
	$lang['strftstabconfigs'] = '&#37197;&#32622;';
	$lang['strftstabdicts'] = '&#23383;&#20856;';
	$lang['strftstabparsers'] = '&#20998;&#26512;&#22120;';
?>
